import request from '@/utils/request'

// 查询家族相簿照片列表
export function listPhoto(query) {
  return request({
    url: '/system/family/photo/list',
    method: 'get',
    params: query
  })
}

// 查询家族相簿照片详细
export function getPhoto(id) {
  return request({
    url: '/system/family/photo/' + id,
    method: 'get'
  })
}

// 新增家族相簿照片
export function addPhoto(data) {
  return request({
    url: '/system/family/photo',
    method: 'post',
    data: data
  })
}

// 修改家族相簿照片
export function updatePhoto(data) {
  return request({
    url: '/system/family/photo',
    method: 'put',
    data: data
  })
}

// 删除家族相簿照片
export function delPhoto(id) {
  return request({
    url: '/system/family/photo/' + id,
    method: 'delete'
  })
}

// 导出家族相簿照片
export function exportPhoto(query) {
  return request({
    url: '/system/family/photo/export',
    method: 'get',
    params: query
  })
}


export function batchUpload(data){
  return request({
   
    url: '/system/family/photo/batchUpload',
    method: 'post',
    data: data
  })
}